# Pysquid

Playbook templating system

See documentation: https://bjarne.gitlab.bjarnessen.no/pysquid

See changelog: https://bjarne.gitlab.bjarnessen.no/pysquid/changelog

To upload to PYPI, run manual stage with CI variables: PYPI_PASSWORD and PYPI_USERNAME